@@ -23,6 +23,7 @@
 #include "agentbase.h"
 #include "agentbase_p.h"
 
+#include "agentmanager.h"
 #include "changerecorder.h"
 #include "controladaptor.h"
 #include "dbusconnectionpool.h"
@@ -50,6 +51,7 @@
 #include <signal.h>
 #include <stdlib.h>
 
+
 //#define EXPERIMENTAL_INPROCESS_AGENTS 1
 
 using namespace Akonadi;
@@ -269,7 +271,10 @@ void AgentBasePrivate::init()
     KApplication::kApplication()->disableSessionManagement();
 #endif
 
-  QTimer::singleShot( 0, q, SLOT( delayedInit() ) );
+  mResourceTypeName = AgentManager::self()->instance(mId).type().name();
+  setProgramName();
+
+  QTimer::singleShot( 0, q, SLOT(delayedInit()) );
 }
 
 void AgentBasePrivate::delayedInit()
@@ -280,6 +285,16 @@ void AgentBasePrivate::delayedInit()
   q->setOnline( mOnline );
 }
 
+void AgentBasePrivate::setProgramName()
+{
+  // ugly, really ugly, if you find another solution, change it and blame me for this code (Andras)
+  QString programName = mResourceTypeName;
+  if ( !mName.isEmpty() ) {
+    programName = i18nc( "Name and type of Akonadi resource", "%1 of type %2", mName, mResourceTypeName ) ;
+  }
+  const_cast<KAboutData*>( KGlobal::mainComponent().aboutData() )->setProgramName( ki18n( programName.toUtf8() ) );
+}
+
 void AgentBasePrivate::itemAdded( const Akonadi::Item &item, const Akonadi::Collection &collection )
 {
   if ( mObserver != 0 )
@@ -718,6 +733,8 @@ void AgentBase::setAgentName( const QString &name )
 
   d->mSettings->sync();
 
+  d->setProgramName();
+
   emit agentNameChanged( d->mName );
 }
 
