@@ -24,7 +24,7 @@
 #include "job_p.h"
 
 #include <kdebug.h>
-
+#include <KLocale>
 using namespace Akonadi;
 
 class Akonadi::CollectionCreateJobPrivate : public JobPrivate
@@ -53,29 +53,30 @@ CollectionCreateJob::~CollectionCreateJob( )
 void CollectionCreateJob::doStart( )
 {
   Q_D( CollectionCreateJob );
-  if ( d->mCollection.parent() < 0 && d->mCollection.parentRemoteId().isEmpty() ) {
+  if ( d->mCollection.parentCollection().id() < 0 && d->mCollection.parentCollection().remoteId().isEmpty() ) {
     setError( Unknown );
-    setErrorText( QLatin1String("Invalid parent") );
+    setErrorText( i18n( "Invalid parent" ) );
     emitResult();
     return;
   }
 
   QByteArray command = d->newTag();
-  if ( d->mCollection.parent() < 0 )
+  if ( d->mCollection.parentCollection().id() < 0 )
     command += " RID";
-  command += " CREATE \"" + d->mCollection.name().toUtf8() + "\" ";
-  if ( d->mCollection.parent() >= 0 )
-    command += QByteArray::number( d->mCollection.parent() );
+  command += " CREATE " + ImapParser::quote( d->mCollection.name().toUtf8() ) + ' ';
+  if ( d->mCollection.parentCollection().id() >= 0 )
+    command += QByteArray::number( d->mCollection.parentCollection().id() );
   else
-    command += ImapParser::quote( d->mCollection.parentRemoteId().toUtf8() );
+    command += ImapParser::quote( d->mCollection.parentCollection().remoteId().toUtf8() );
   command += " (";
   if ( !d->mCollection.contentMimeTypes().isEmpty() )
   {
     QList<QByteArray> cList;
-    foreach( const QString &s, d->mCollection.contentMimeTypes() ) cList << s.toLatin1();
+    foreach ( const QString &s, d->mCollection.contentMimeTypes() ) cList << s.toLatin1();
     command += "MIMETYPE (" + ImapParser::join( cList, QByteArray(" ") ) + ')';
   }
-  command += " REMOTEID \"" + d->mCollection.remoteId().toUtf8() + '"';
+  command += " REMOTEID " + ImapParser::quote( d->mCollection.remoteId().toUtf8() );
+  command += " REMOTEREVISION " + ImapParser::quote( d->mCollection.remoteRevision().toUtf8() );
   foreach ( Attribute* attr, d->mCollection.attributes() )
     command += ' ' + attr->type() + ' ' + ImapParser::quote( attr->serialized() );
   command += ' ' + ProtocolHelper::cachePolicyToByteArray( d->mCollection.cachePolicy() );
@@ -101,9 +102,10 @@ void CollectionCreateJob::doHandleResponse(const QByteArray & tag, const QByteAr
     if ( !col.isValid() )
       return;
 
-    col.setParent( d->mCollection.parent() );
+    col.setParentCollection( d->mCollection.parentCollection() );
     col.setName( d->mCollection.name() );
     col.setRemoteId( d->mCollection.remoteId() );
+    col.setRemoteRevision( d->mCollection.remoteRevision() );
     d->mCollection = col;
   } else {
     Job::doHandleResponse( tag, data );
