@@ -132,7 +132,10 @@ QString StandardContactFormatter::toHtml( HtmlForm form ) const
 
     formattedAddress = formattedAddress.replace( QLatin1Char( '\n' ), QLatin1String( "<br>" ) );
 
-    const QString url = QString::fromLatin1( "<a href=\"address:?index=%1\">%2</a>" ).arg( counter).arg( formattedAddress );
+    const QString url = QString::fromLatin1( "%1 <a href=\"address:?index=%2\"><img src=\"map_icon\" alt=\"%3\"/></a>" )
+                                           .arg( formattedAddress )
+                                           .arg( counter )
+                                           .arg( i18n( "Show address on map" ) );
     counter++;
 
     dynamicPart += rowFmtStr
@@ -257,7 +260,20 @@ QString StandardContactFormatter::toHtml( HtmlForm form ) const
   strAddr.append( dynamicPart );
   strAddr.append( notes );
   strAddr.append( customData );
-  strAddr.append( QString::fromLatin1( "</table></div>\n" ) );
+  strAddr.append( QString::fromLatin1( "</table>" ) );
+
+#ifdef HAVE_PRISON
+  strAddr.append( QString::fromLatin1(
+    "<p align=\"center\">"
+    "<img src=\"%1\" vspace=\"1\">"
+    "<img src=\"%2\" vspace=\"1\">"
+    "</p>"
+                           )
+    .arg( QLatin1String( "datamatrix" ) )
+    .arg( QLatin1String( "qrcode" ) ) );
+#endif // HAVE_PRISON
+
+  strAddr.append( QString::fromLatin1( "</div>\n" ) );
 
   if ( form == EmbeddableForm )
     return strAddr;
