@@ -225,9 +225,6 @@ class StandardMailActionManager::Private
 
       mGenericManager->setMimeTypeFilter( QStringList() << KMime::Message::mimeType() );
       mGenericManager->setCapabilityFilter( QStringList() << QLatin1String( "Resource" ) );
-      mGenericManager->interceptAction( Akonadi::StandardActionManager::ManageLocalSubscriptions );
-      connect( mGenericManager->action( StandardActionManager::ManageLocalSubscriptions ), SIGNAL( triggered( bool ) ),
-               mParent, SLOT( slotMailLocalSubscription() ) );
     }
 
     ~Private()
@@ -304,13 +301,14 @@ class StandardMailActionManager::Private
 
       bool enableMarkAllAsRead = false;
       bool enableMarkAllAsUnread = false;
+      bool canDeleteItem = true;
       if ( collectionIsSelected ) {
         const Collection collection = selectedCollections.first();
         if ( collection.isValid() ) {
           const Akonadi::CollectionStatistics stats = collection.statistics();
           enableMarkAllAsRead = (stats.unreadCount() > 0);
           enableMarkAllAsUnread = (stats.count() != stats.unreadCount());
-
+          canDeleteItem = collection.rights() & Akonadi::Collection::CanDeleteItem;
           const bool isSystemFolder = (collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Inbox ) ||
                                        collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Outbox ) ||
                                        collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::SentMail ) ||
@@ -327,7 +325,9 @@ class StandardMailActionManager::Private
       }
 
       if ( mActions.contains( Akonadi::StandardMailActionManager::MoveToTrash ) )
-        mActions.value( Akonadi::StandardMailActionManager::MoveToTrash )->setEnabled( itemIsSelected );
+        mActions.value( Akonadi::StandardMailActionManager::MoveToTrash )->setEnabled( itemIsSelected && canDeleteItem );
+      if ( mActions.contains( Akonadi::StandardMailActionManager::RemoveDuplicates ) )
+        mActions.value( Akonadi::StandardMailActionManager::RemoveDuplicates )->setEnabled( canDeleteItem );
 
       QAction *action = mActions.value( Akonadi::StandardMailActionManager::MarkAllMailAsRead );
       if ( action )
@@ -499,14 +499,6 @@ class StandardMailActionManager::Private
       command->execute();
     }
 
-    void slotMailLocalSubscription()
-    {
-#ifndef Q_OS_WINCE
-      SubscriptionDialog* dlg = new SubscriptionDialog( KMime::Message::mimeType(), mParentWidget );
-      dlg->show();
-#endif
-    }
-
     KActionCollection *mActionCollection;
     QWidget *mParentWidget;
     StandardActionManager *mGenericManager;
