@@ -36,13 +36,49 @@ using namespace Akonadi;
 
 static const int PipelineSize = 5;
 
-MonitorPrivate::MonitorPrivate(Monitor * parent) :
+QObject* MonitorDependeciesFactory::createNotificationSource(QObject *parent)
+{
+  org::freedesktop::Akonadi::NotificationManager manager(
+          QLatin1String( "org.freedesktop.Akonadi" ),
+          QLatin1String( "/notifications" ),
+          DBusConnectionPool::threadConnection() );
+
+  QDBusObjectPath p = manager.subscribe( KGlobal::mainComponent().componentName() );
+  if ( manager.lastError().isValid() ) {
+    // :TODO: What to do?
+    return 0;
+  }
+
+  org::freedesktop::Akonadi::NotificationSource *notificationSource = new org::freedesktop::Akonadi::NotificationSource(
+              QLatin1String( "org.freedesktop.Akonadi" ),
+              p.path(),
+              DBusConnectionPool::threadConnection(), parent );
+
+  if ( !notificationSource ) {
+    // :TODO: error handling
+    return 0;
+  }
+  return notificationSource;
+}
+
+CollectionCache* MonitorDependeciesFactory::createCollectionCache(int maxCapacity, Session *session)
+{
+  return new CollectionCache(maxCapacity, session);
+}
+
+ItemCache* MonitorDependeciesFactory::createItemCache(int maxCapacity, Session* session)
+{
+  return new ItemCache(maxCapacity, session);
+}
+
+MonitorPrivate::MonitorPrivate( MonitorDependeciesFactory *dependenciesFactory_, Monitor * parent) :
   q_ptr( parent ),
+  dependenciesFactory(dependenciesFactory_ ? dependenciesFactory_ : new MonitorDependeciesFactory),
   notificationSource( 0 ),
   monitorAll( false ),
   session( Session::defaultSession() ),
-  collectionCache( 3*PipelineSize, session ), // needs to be at least 3x pipeline size for the collection move case
-  itemCache( PipelineSize, session ), // needs to be at least 1x pipeline size
+  collectionCache( 0 ),
+  itemCache( 0 ),
   fetchCollection( false ),
   fetchCollectionStatistics( false ),
   useRefCounting( false )
@@ -51,8 +87,13 @@ MonitorPrivate::MonitorPrivate(Monitor * parent) :
 
 void MonitorPrivate::init()
 {
-  QObject::connect( &collectionCache, SIGNAL( dataAvailable() ), q_ptr, SLOT( dataAvailable() ) );
-  QObject::connect( &itemCache, SIGNAL( dataAvailable() ), q_ptr, SLOT( dataAvailable() ) );
+  // needs to be at least 3x pipeline size for the collection move case
+  collectionCache = dependenciesFactory->createCollectionCache(3*PipelineSize, session);
+  // needs to be at least 1x pipeline size
+  itemCache = dependenciesFactory->createItemCache(PipelineSize, session);
+
+  QObject::connect( collectionCache, SIGNAL( dataAvailable() ), q_ptr, SLOT( dataAvailable() ) );
+  QObject::connect( itemCache, SIGNAL( dataAvailable() ), q_ptr, SLOT( dataAvailable() ) );
   QObject::connect( ServerManager::self(), SIGNAL(stateChanged(Akonadi::ServerManager::State)),
                     q_ptr, SLOT(serverStateChanged(Akonadi::ServerManager::State)) );
 
@@ -68,26 +109,10 @@ bool MonitorPrivate::connectToNotificationManager()
   delete notificationSource;
   notificationSource = 0;
 
-  org::freedesktop::Akonadi::NotificationManager manager(
-          QLatin1String( "org.freedesktop.Akonadi" ),
-          QLatin1String( "/notifications" ),
-          DBusConnectionPool::threadConnection() );
+  notificationSource = dependenciesFactory->createNotificationSource(q_ptr);
 
-  QDBusObjectPath p = manager.subscribe( KGlobal::mainComponent().componentName() );
-  if ( manager.lastError().isValid() ) {
-    // :TODO: What to do?
+  if (!notificationSource)
     return false;
-  }
-
-  notificationSource = new org::freedesktop::Akonadi::NotificationSource(
-              QLatin1String( "org.freedesktop.Akonadi" ),
-              p.path(),
-              DBusConnectionPool::threadConnection(), q_ptr );
-
-  if ( !notificationSource ) {
-    // :TODO: error handling
-    return false;
-  }
 
   QObject::connect( notificationSource, SIGNAL( notify( Akonadi::NotificationMessage::List ) ),
                     q_ptr, SLOT( slotNotify( Akonadi::NotificationMessage::List ) ) );
@@ -204,17 +229,6 @@ bool MonitorPrivate::acceptNotification( const NotificationMessage & msg )
   return false;
 }
 
-void MonitorPrivate::dispatchNotifications()
-{
-  while ( pipeline.size() < pipelineSize() && !pendingNotifications.isEmpty() ) {
-    const NotificationMessage msg = pendingNotifications.dequeue();
-    if ( ensureDataAvailable( msg ) && pipeline.isEmpty() )
-      emitNotification( msg );
-    else
-      pipeline.enqueue( msg );
-  }
-}
-
 void MonitorPrivate::cleanOldNotifications()
 {
   for ( NotificationMessage::List::iterator it = pipeline.begin(); it != pipeline.end(); ) {
@@ -236,19 +250,19 @@ bool MonitorPrivate::ensureDataAvailable( const NotificationMessage &msg )
 {
   bool allCached = true;
   if ( fetchCollection ) {
-    if ( !collectionCache.ensureCached( msg.parentCollection(), mCollectionFetchScope ) )
+    if ( !collectionCache->ensureCached( msg.parentCollection(), mCollectionFetchScope ) )
       allCached = false;
-    if ( msg.operation() == NotificationMessage::Move && !collectionCache.ensureCached( msg.parentDestCollection(), mCollectionFetchScope ) )
+    if ( msg.operation() == NotificationMessage::Move && !collectionCache->ensureCached( msg.parentDestCollection(), mCollectionFetchScope ) )
       allCached = false;
   }
   if ( msg.operation() == NotificationMessage::Remove )
     return allCached; // the actual object is gone already, nothing to fetch there
 
   if ( msg.type() == NotificationMessage::Item && !mItemFetchScope.isEmpty() ) {
-    if ( !itemCache.ensureCached( msg.uid(), mItemFetchScope ) )
+    if ( !itemCache->ensureCached( msg.uid(), mItemFetchScope ) )
       allCached = false;
   } else if ( msg.type() == NotificationMessage::Collection && fetchCollection ) {
-    if ( !collectionCache.ensureCached( msg.uid(), mCollectionFetchScope ) )
+    if ( !collectionCache->ensureCached( msg.uid(), mCollectionFetchScope ) )
       allCached = false;
   }
   return allCached;
@@ -256,17 +270,17 @@ bool MonitorPrivate::ensureDataAvailable( const NotificationMessage &msg )
 
 bool MonitorPrivate::emitNotification( const NotificationMessage &msg )
 {
-  const Collection parent = collectionCache.retrieve( msg.parentCollection() );
+  const Collection parent = collectionCache->retrieve( msg.parentCollection() );
   Collection destParent;
   if ( msg.operation() == NotificationMessage::Move )
-    destParent = collectionCache.retrieve( msg.parentDestCollection() );
+    destParent = collectionCache->retrieve( msg.parentDestCollection() );
 
   bool someoneWasListening = false;
   if ( msg.type() == NotificationMessage::Collection ) {
-    const Collection col = collectionCache.retrieve( msg.uid() );
+    const Collection col = collectionCache->retrieve( msg.uid() );
     someoneWasListening = emitCollectionNotification( msg, col, parent, destParent );
   } else if ( msg.type() == NotificationMessage::Item ) {
-    const Item item = itemCache.retrieve( msg.uid() );
+    const Item item = itemCache->retrieve( msg.uid() );
     someoneWasListening = emitItemNotification( msg, item, parent, destParent );
   }
 
@@ -276,28 +290,12 @@ bool MonitorPrivate::emitNotification( const NotificationMessage &msg )
   return someoneWasListening;
 }
 
-void MonitorPrivate::dataAvailable()
-{
-  while ( !pipeline.isEmpty() ) {
-    const NotificationMessage msg = pipeline.head();
-    if ( ensureDataAvailable( msg ) ) {
-      // dequeue should be before emit, otherwise stuff might happen (like dataAvailable
-      // being called again) and we end up dequeuing an empty pipeline
-      pipeline.dequeue();
-      emitNotification( msg );
-    } else {
-      break;
-    }
-  }
-  dispatchNotifications();
-}
-
 void MonitorPrivate::updatePendingStatistics( const NotificationMessage &msg )
 {
   if ( msg.type() == NotificationMessage::Item ) {
     notifyCollectionStatisticsWatchers( msg.parentCollection(), msg.resource() );
     // FIXME use the proper resource of the target collection, for cross resource moves
-    notifyCollectionStatisticsWatchers( msg.parentDestCollection(), msg.resource() );
+    notifyCollectionStatisticsWatchers( msg.parentDestCollection(), msg.destinationResource() );
   } else if ( msg.type() == NotificationMessage::Collection && msg.operation() == NotificationMessage::Remove ) {
     // no need for statistics updates anymore
     recentlyChangedCollections.remove( msg.uid() );
@@ -337,16 +335,41 @@ void MonitorPrivate::slotFlushRecentlyChangedCollections()
   recentlyChangedCollections.clear();
 }
 
-void MonitorPrivate::appendAndCompress( const NotificationMessage &msg  )
+bool MonitorPrivate::translateAndCompress( QQueue<NotificationMessage> &notificationQueue, const NotificationMessage &msg  )
 {
-  if ( !useRefCounting || msg.operation() != NotificationMessage::Move || msg.type() != NotificationMessage::Item )
-    return NotificationMessage::appendAndCompress( pendingNotifications, msg );
+  // We have to split moves into insert or remove if the source or destination
+  // is not monitored.
+  if ( msg.operation() != NotificationMessage::Move ) {
+    bool appended = false;
+    NotificationMessage::appendAndCompress( notificationQueue, msg, &appended );
+    return appended;
+  }
 
-  bool sourceWatched = refCountMap.contains( msg.parentCollection() ) || m_buffer.isBuffered( msg.parentCollection() );
-  bool destWatched = refCountMap.contains( msg.parentDestCollection() ) || m_buffer.isBuffered( msg.parentDestCollection() );
+  bool sourceWatched = false;
+  bool destWatched = false;
 
-  if ( sourceWatched && destWatched )
-    return NotificationMessage::appendAndCompress( pendingNotifications, msg );
+  if ( useRefCounting && msg.type() == NotificationMessage::Item ) {
+    sourceWatched = refCountMap.contains( msg.parentCollection() ) || m_buffer.isBuffered( msg.parentCollection() );
+    destWatched = refCountMap.contains( msg.parentDestCollection() ) || m_buffer.isBuffered( msg.parentDestCollection() );
+  } else {
+    if ( !resources.isEmpty() ) {
+      sourceWatched = resources.contains( msg.resource() );
+      destWatched = isMoveDestinationResourceMonitored( msg );
+    }
+    if ( !sourceWatched )
+      sourceWatched = isCollectionMonitored( msg.parentCollection() );
+    if ( !destWatched )
+      destWatched = isCollectionMonitored( msg.parentDestCollection() );
+  }
+
+  if ( !sourceWatched && !destWatched )
+    return false;
+
+  if ( sourceWatched && destWatched ) {
+    bool appended = false;
+    NotificationMessage::appendAndCompress( notificationQueue, msg, &appended );
+    return appended;
+  }
 
   if ( sourceWatched )
   {
@@ -354,7 +377,9 @@ void MonitorPrivate::appendAndCompress( const NotificationMessage &msg  )
     NotificationMessage removalMessage = msg;
     removalMessage.setOperation( NotificationMessage::Remove );
     removalMessage.setParentDestCollection( -1 );
-    return NotificationMessage::appendAndCompress( pendingNotifications, removalMessage );
+    bool appended = false;
+    NotificationMessage::appendAndCompress( notificationQueue, removalMessage, &appended );
+    return appended;
   }
 
   // Transform into an insertion
@@ -362,22 +387,65 @@ void MonitorPrivate::appendAndCompress( const NotificationMessage &msg  )
   insertionMessage.setOperation( NotificationMessage::Add );
   insertionMessage.setParentCollection( msg.parentDestCollection() );
   insertionMessage.setParentDestCollection( -1 );
-  NotificationMessage::appendAndCompress( pendingNotifications, insertionMessage );
+  bool appended = false;
+  NotificationMessage::appendAndCompress( notificationQueue, insertionMessage, &appended );
+  return appended;
 }
 
+/*
+
+  server notification --> ?accepted --> pendingNotifications --> ?dataAvailable --> emit
+                                  |                                           |
+                                  x --> discard                               x --> pipeline
+
+  fetchJobDone --> pipeline ?dataAvailable --> emit
+ */
+
 void MonitorPrivate::slotNotify( const NotificationMessage::List &msgs )
 {
   foreach ( const NotificationMessage &msg, msgs ) {
     invalidateCaches( msg );
     updatePendingStatistics( msg );
     if ( acceptNotification( msg ) ) {
-      appendAndCompress( msg );
+      translateAndCompress( pendingNotifications, msg );
     }
   }
 
   dispatchNotifications();
 }
 
+void MonitorPrivate::flushPipeline()
+{
+  while ( !pipeline.isEmpty() ) {
+    const NotificationMessage msg = pipeline.head();
+    if ( ensureDataAvailable( msg ) ) {
+      // dequeue should be before emit, otherwise stuff might happen (like dataAvailable
+      // being called again) and we end up dequeuing an empty pipeline
+      pipeline.dequeue();
+      emitNotification( msg );
+    } else {
+      break;
+    }
+  }
+}
+
+void MonitorPrivate::dataAvailable()
+{
+  flushPipeline();
+  dispatchNotifications();
+}
+
+void MonitorPrivate::dispatchNotifications()
+{
+  while ( pipeline.size() < pipelineSize() && !pendingNotifications.isEmpty() ) {
+    const NotificationMessage msg = pendingNotifications.dequeue();
+    if ( ensureDataAvailable( msg ) && pipeline.isEmpty() )
+      emitNotification( msg );
+    else
+      pipeline.enqueue( msg );
+  }
+}
+
 bool MonitorPrivate::emitItemNotification( const NotificationMessage &msg, const Item &item,
                                            const Collection &collection, const Collection &collectionDest  )
 {
@@ -562,9 +630,9 @@ void MonitorPrivate::invalidateCaches( const NotificationMessage &msg )
   // remove invalidates
   if ( msg.operation() == NotificationMessage::Remove ) {
     if ( msg.type() == NotificationMessage::Collection ) {
-      collectionCache.invalidate( msg.uid() );
+      collectionCache->invalidate( msg.uid() );
     } else if ( msg.type() == NotificationMessage::Item ) {
-      itemCache.invalidate( msg.uid() );
+      itemCache->invalidate( msg.uid() );
     }
   }
 
@@ -574,16 +642,16 @@ void MonitorPrivate::invalidateCaches( const NotificationMessage &msg )
         || msg.operation() == NotificationMessage::Move
         || msg.operation() == NotificationMessage::Subscribe ) {
     if ( msg.type() == NotificationMessage::Collection ) {
-      collectionCache.update( msg.uid(), mCollectionFetchScope );
+      collectionCache->update( msg.uid(), mCollectionFetchScope );
     } else if ( msg.type() == NotificationMessage::Item ) {
-      itemCache.update( msg.uid(), mItemFetchScope );
+      itemCache->update( msg.uid(), mItemFetchScope );
     }
   }
 }
 
 void MonitorPrivate::invalidateCache( const Collection &col )
 {
-  collectionCache.update( col.id(), mCollectionFetchScope );
+  collectionCache->update( col.id(), mCollectionFetchScope );
 }
 
 void MonitorPrivate::ref( Collection::Id id )
