@@ -52,6 +52,9 @@ namespace KABC {
     KABC::StdAddressBook::save( ticket );
   }
   \endcode
+
+  @deprecated Port to libakonadi-kontact. For instance using Akonadi::ContactSearchJob.
+  See http://techbase.kde.org/Development/AkonadiPorting/AddressBook for details.
 */
 class KABC_EXPORT_DEPRECATED StdAddressBook : public AddressBook
 {
