@@ -19,6 +19,7 @@
 
 #include "listjob.h"
 
+#include <boost/bind.hpp>
 #include <QtCore/QTimer>
 #include <KDE/KLocale>
 
@@ -177,6 +178,7 @@ void ListJob::handleResponse( const Message &response )
   if ( handleErrorReplies( response ) == NotHandled ) {
     if ( response.content.size() >= 5 && response.content[1].toString() == d->command ) {
       QList<QByteArray> flags = response.content[2].toList();
+      std::transform( flags.begin(), flags.end(), flags.begin(), boost::bind(&QByteArray::toLower, _1) );
       QByteArray separator = response.content[3].toString();
       if ( separator.isEmpty() ) {
         // Defaults to / for servers reporting an empty list
