@@ -73,7 +73,9 @@ class KIMAP_EXPORT SessionPrivate : public QObject
     void doStartNext();
     void jobDone( KJob *job );
     void jobDestroyed( QObject *job );
+    void clearJobQueue();
     void responseReceived( const KIMAP::Message &response );
+    void setState(Session::State state);
 
     void socketConnected();
     void socketDisconnected();
@@ -100,6 +102,7 @@ class KIMAP_EXPORT SessionPrivate : public QObject
     QByteArray selectTag;
     QByteArray closeTag;
 
+    QString userName;
     QByteArray greeting;
     QByteArray currentMailBox;
     QByteArray upcomingMailBox;
